@@ -1,4 +1,6 @@
 """Define the tag command."""
+from __future__ import annotations
+
 import asyncio
 import json
 
@@ -14,7 +16,12 @@ def create(
     ctx: typer.Context,
     tag_name: str = typer.Argument(..., help="The tag to create."),
 ) -> None:
-    """Create a tag."""
+    """Create a tag.
+
+    Args:
+        ctx: A Typer Context object.
+        tag_name: The tag to create.
+    """
     data = asyncio.run(ctx.obj.client.tags.async_create(tag_name))
     typer.echo(json.dumps(data))
 
@@ -35,7 +42,13 @@ def get_all(
         help="The index from which to return results.",
     ),
 ) -> None:
-    """Get all tags."""
+    """Get all tags.
+
+    Args:
+        ctx: A Typer Context object.
+        limit: The number of tags to return.
+        offset: The index from which to return results.
+    """
     api_kwargs = generate_api_payload(
         (
             (CONF_LIMIT, limit),
@@ -52,13 +65,18 @@ def get_by_id(
     ctx: typer.Context,
     tag_id: int = typer.Argument(..., help="The ID of a tag to retrieve."),
 ) -> None:
-    """Get a tag by its linkding ID."""
+    """Get a tag by its linkding ID.
+
+    Args:
+        ctx: A Typer Context object.
+        tag_id: The ID of a tag to retrieve.
+    """
     data = asyncio.run(ctx.obj.client.tags.async_get_single(tag_id))
     typer.echo(json.dumps(data))
 
 
 @log_exception()
-def main(ctx: typer.Context) -> None:
+def main(_: typer.Context) -> None:
     """Interact with tags."""
     pass
 
