@@ -3,8 +3,8 @@ from __future__ import annotations
 
 from typing import cast
 
-from ruamel.yaml import YAML
 import typer
+from ruamel.yaml import YAML
 
 from linkding_cli.const import CONF_TOKEN, CONF_URL, CONF_VERBOSE, LOGGER
 from linkding_cli.errors import ConfigError
@@ -16,7 +16,14 @@ class Config:
     """Define the config manager object."""
 
     def __init__(self, ctx: typer.Context) -> None:
-        """Initialize."""
+        """Initialize.
+
+        Args:
+            ctx: A Typer Context object.
+
+        Raises:
+            ConfigError: Raised upon invalid config
+        """
         LOGGER.debug("Command: %s", ctx.invoked_subcommand)
         LOGGER.debug("Arguments: %s", ctx.args)
         LOGGER.debug("Options: %s", ctx.params)
@@ -48,20 +55,36 @@ class Config:
         LOGGER.debug("Loaded Config: %s", self)
 
     def __str__(self) -> str:
-        """Define the string representation."""
+        """Define the string representation.
+
+        Returns:
+            A string representation.
+        """
         return f"<Config token={self.token} url={self.url} verbose={self.verbose}>"
 
     @property
     def token(self) -> str:
-        """Return the linkding token."""
+        """Return the linkding API token.
+
+        Returns:
+            The linkding API token.
+        """
         return cast(str, self._config[CONF_TOKEN])
 
     @property
     def url(self) -> str:
-        """Return the linkding URL."""
+        """Return the linkding URL.
+
+        Returns:
+            The linkding API token.
+        """
         return cast(str, self._config[CONF_URL])
 
     @property
     def verbose(self) -> bool:
-        """Return the verbosity level."""
+        """Return the verbosity level.
+
+        Returns:
+            The verbosity level.
+        """
         return cast(bool, self._config[CONF_VERBOSE])
